/*
 * Copyright IBM Corp. 2008
 * All rights reserved. This program and the accompanying materials 
 * are made available under the terms of the Common Public License v1.0
 * which accompanies this distribution, and is available at
 * http://www.ibm.com/developerworks/library/os-cpl.html
 *
 * Authors:		Sven Schuetz <sven@de.ibm.com>
 * 
 * File:		vlib_sg.c
 * 
 * Description:
 * All calls that use sg_utils library.
 * 
 */
 
 /**
 * @file vlib_sg.c
 * @brief All calls that use sg_utils library.
 */

#include "vlib.h"

#define INTERVAL	10000000
#define RETRIES		1500

HBA_STATUS sgutils_SendScsiInquiry(char* sg_dev, HBA_UINT8 EVPD, 
				HBA_UINT32 PageCode, void *pRspBuffer,
				HBA_UINT32 RspBufferSize, void *pSenseBuffer,
				HBA_UINT32 SenseBufferSize)
{
	char dev_path[32];
	int sg_fd, res;

	if(sg_dev == NULL) {
		return HBA_STATUS_ERROR;
	}
	
	strcpy(dev_path, "/dev/");
	strcat(dev_path, sg_dev);
	
	sg_fd = sg_cmds_open_device(dev_path, 0, 0);
	if (sg_fd < 0) {
		return HBA_STATUS_ERROR;
	}
	memset(pRspBuffer, 0x0, RspBufferSize);
	res = sg_ll_inquiry(sg_fd, 0, EVPD, PageCode, pRspBuffer,
							RspBufferSize, 0, 0);
	if(res < 0) {
		sg_cmds_close_device(sg_fd);
		return HBA_STATUS_SCSI_CHECK_CONDITION;
	}
	
	res = sg_cmds_close_device(sg_fd);
	if(res < 0) {
		return HBA_STATUS_ERROR;
	}
	return HBA_STATUS_OK;
}

HBA_STATUS sgutils_SendReportLUNs(char* sg_dev, void *pRspBuffer,
				HBA_UINT32 RspBufferSize)
{
	int sg_fd, res, count = 0;
	char dev_path[32];
	struct timespec t;
	
	strcpy(dev_path, "/dev/");
	if(sg_dev == NULL) {
		return HBA_STATUS_ERROR;
	}
	
	strcat(dev_path, sg_dev);
	
	t.tv_nsec = INTERVAL;
	t.tv_sec = 0;
	sg_fd = sg_cmds_open_device(dev_path, 0, 0);
	while (sg_fd < 0 && count < RETRIES) {
		nanosleep(&t, NULL);
		sg_fd = sg_cmds_open_device(dev_path, 0, 0);
		count++;
	}
	if (sg_fd < 0) {
		return HBA_STATUS_ERROR;
	}
	memset(pRspBuffer, 0x0, RspBufferSize);
	res = sg_ll_report_luns(sg_fd, 0, pRspBuffer, RspBufferSize, 0, 0);
	if(res < 0) {
		sg_cmds_close_device(sg_fd);
		return HBA_STATUS_SCSI_CHECK_CONDITION;
	}
	
	res = sg_cmds_close_device(sg_fd);
	if(res < 0) {
		return HBA_STATUS_ERROR;
	}
	return HBA_STATUS_OK;
}
